==============
trame-dockview
==============

Trame wrapper to a Docking Layout Manager


* Free software: MIT License


Installing
----------
Build and install the Vue components

.. code-block:: console

    cd vue-components
    npm i
    npm run build
    cd -

Install the application

.. code-block:: console

    pip install -e ".[dev]"



Features
--------

* TODO
